@@ -19,18 +19,15 @@
 #' - [draws_median()]
 #' - [draws_mean()]
 #' - [draws_mode()]
+#' - [draws_sd()]
+#' - [draws_var()]
+#' - [draws_cv()]
 #' - [draws_ci()]
 #' - [draws_quantile()]
 #'
 #' Apply arbitrary function across draws:
 #' - [draws_fun()]
 #'
-#' For additional functions for summarising random draws, see
-#' [tidybayes](https://CRAN.R-project.org/package=tidybayes)
-#' and [ggdist](https://CRAN.R-project.org/package=ggdist).
-#' Function [as_list_col()] converts rvecs into a
-#' format that `tidybayes` and `ggdist` can work with.
-#'
 #' @examples
 #' m <- rbind(a = c(TRUE,  FALSE,  TRUE),
 #'            b = c(TRUE,  TRUE,   TRUE),
@@ -41,61 +38,61 @@
 #' draws_any(x)
 #' @export
 draws_all <- function(x, na_rm = FALSE) {
-    UseMethod("draws_all")
+  UseMethod("draws_all")
 }
 
 ## HAS_TESTS
 #' @rdname draws_all
 #' @export
 draws_all.rvec_chr <- function(x, na_rm = FALSE) {
-    cli::cli_abort("{.fun all} not defined for character.")
+  cli::cli_abort("{.fun all} not defined for character.")
 }
 
 ## HAS_TESTS
 #' @rdname draws_all
 #' @export
 draws_all.rvec <- function(x, na_rm = FALSE) {
-    check_flag(na_rm)
-    m <- field(x, "data")
-    if (nrow(m) == 0L)
-        TRUE ## base::all returns TRUE with zero-length 'x'
-    else {
-        if (!is.logical(m))
-            cli::cli_warn("Coercing from type {.val {typeof(m)}} to type {.val logical}.")
-        ans <- matrixStats::rowAlls(m, na.rm = na_rm)
-        names(ans) <- rownames(m)
-        ans
-    }
+  check_flag(na_rm)
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    TRUE ## base::all returns TRUE with zero-length 'x'
+  else {
+    if (!is.logical(m))
+      cli::cli_warn("Coercing from type {.val {typeof(m)}} to type {.val logical}.")
+    ans <- matrixStats::rowAlls(m, na.rm = na_rm)
+    names(ans) <- rownames(m)
+    ans
+  }
 }
 
 #' @rdname draws_all
 #' @export
 draws_any <- function(x, na_rm = FALSE) {
-    UseMethod("draws_any")
+  UseMethod("draws_any")
 }
 
 ## HAS_TESTS
 #' @rdname draws_all
 #' @export
 draws_any.rvec_chr <- function(x, na_rm = FALSE) {
-    cli::cli_abort("{.fun any} not defined for character.")
+  cli::cli_abort("{.fun any} not defined for character.")
 }
 
 ## HAS_TESTS
 #' @rdname draws_all
 #' @export
 draws_any.rvec <- function(x, na_rm = FALSE) {
-    check_flag(na_rm)
-    m <- field(x, "data")
-    if (nrow(m) == 0L)
-        FALSE ## base::any returns FALSE with zero-length 'x'
-    else {
-        if (!is.logical(m))
-            cli::cli_warn("Coercing from type {.val {typeof(m)}} to type {.val logical}.")
-        ans <- matrixStats::rowAnys(m, na.rm = na_rm)
-        names(ans) <- rownames(m)
-        ans
-    }
+  check_flag(na_rm)
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    FALSE ## base::any returns FALSE with zero-length 'x'
+  else {
+    if (!is.logical(m))
+      cli::cli_warn("Coercing from type {.val {typeof(m)}} to type {.val logical}.")
+    ans <- matrixStats::rowAnys(m, na.rm = na_rm)
+    names(ans) <- rownames(m)
+    ans
+  }
 }
 
 
@@ -104,7 +101,7 @@ draws_any.rvec <- function(x, na_rm = FALSE) {
 #' Credible Intervals from Random Draws
 #'
 #' Summarise the distribution of random draws
-#' in an `rvec`, using  credible intervals.
+#' in an rvec, using  credible intervals.
 #'
 #' @section Warning:
 #'
@@ -145,17 +142,14 @@ draws_any.rvec <- function(x, na_rm = FALSE) {
 #' - [draws_median()]
 #' - [draws_mean()]
 #' - [draws_mode()]
+#' - [draws_sd()]
+#' - [draws_var()]
+#' - [draws_cv()]
 #' - [draws_quantile()]
 #'
 #' Apply arbitrary function across draws:
 #' - [draws_fun()]
 #'
-#' For additional functions for summarising random draws, see
-#' [tidybayes](https://CRAN.R-project.org/package=tidybayes)
-#' and [ggdist](https://CRAN.R-project.org/package=ggdist).
-#' Function [as_list_col()] converts rvecs into a
-#' format that `tidybayes` and `ggdist` can work with.
-#'
 #' @examples
 #' set.seed(0)
 #' m <- rbind(a = rnorm(100, mean = 5, sd = 2),
@@ -183,7 +177,7 @@ draws_ci <- function(x,
                      width = 0.95,
                      prefix = NULL,
                      na_rm = FALSE) {
-    UseMethod("draws_ci")
+  UseMethod("draws_ci")
 }
 
 ## HAS_TESTS
@@ -235,7 +229,7 @@ draws_ci.rvec_chr <- function(x,
                               width = 0.95,
                               prefix = NULL,
                               na_rm = FALSE) {
-    cli::cli_abort("Credible intervals not defined for character.")
+  cli::cli_abort("Credible intervals not defined for character.")
 }
 
 
@@ -243,9 +237,9 @@ draws_ci.rvec_chr <- function(x,
 
 #' Medians, Means, and Modes Across Random Draws
 #'
-#' Summarise the distribution of random draws
-#' in an `rvec`, using means, medians, or modes.
-#'
+#' Use means, medians, or modes to
+#' summarise the distribution of random draws
+#' in an rvec.
 #'
 #' When `method` is `"mode"`, `reduce_rvec()`
 #' returns the most common value for each
@@ -262,18 +256,15 @@ draws_ci.rvec_chr <- function(x,
 #' - [draws_any()]
 #' - [draws_min()]
 #' - [draws_max()]
+#' - [draws_sd()]
+#' - [draws_var()]
+#' - [draws_cv()]
 #' - [draws_ci()]
 #' - [draws_quantile()]
 #'
 #' Apply arbitrary function across draws:
 #' - [draws_fun()]
 #'
-#' For additional functions for summarising random draws, see
-#' [tidybayes](https://CRAN.R-project.org/package=tidybayes)
-#' and [ggdist](https://CRAN.R-project.org/package=ggdist).
-#' Function [as_list_col()] converts rvecs into a
-#' format that `tidybayes` and `ggdist` can work with.
-#'
 #' @examples
 #' m <- rbind(a = c(1, 1, 1, 2, 3),
 #'            b = c(2, 4, 0, 2, 3),
@@ -285,94 +276,94 @@ draws_ci.rvec_chr <- function(x,
 #' draws_mode(x)
 #' @export
 draws_median <- function(x, na_rm = FALSE) {
-    UseMethod("draws_median")
+  UseMethod("draws_median")
 }
 
 ## HAS_TESTS
 #' @rdname draws_median
 #' @export
 draws_median.rvec_chr <- function(x, na_rm = FALSE) {
-    cli::cli_abort("Median not defined for character.")
+  cli::cli_abort("Median not defined for character.")
 }
 
 ## HAS_TESTS
 #' @rdname draws_median
 #' @export
 draws_median.rvec <- function(x, na_rm = FALSE) {
-    check_flag(na_rm)
-    m <- field(x, "data")
-    if (nrow(m) == 0L)
-        NA_real_ ## base::median returns NA with zero-length 'x'
-    else {
-        m <- 1 * m
-        ans <- matrixStats::rowMedians(m, na.rm = na_rm)
-        names(ans) <- rownames(m)
-        ans
-    }
+  check_flag(na_rm)
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    NA_real_ ## base::median returns NA with zero-length 'x'
+  else {
+    m <- 1 * m
+    ans <- matrixStats::rowMedians(m, na.rm = na_rm)
+    names(ans) <- rownames(m)
+    ans
+  }
 }
 
 #' @rdname draws_median
 #' @export
 draws_mean <- function(x, na_rm = FALSE) {
-    UseMethod("draws_mean")
+  UseMethod("draws_mean")
 }
 
 ## HAS_TESTS
 #' @rdname draws_median
 #' @export
 draws_mean.rvec <- function(x, na_rm = FALSE) {
-    check_flag(na_rm)
-    m <- field(x, "data")
-    if (nrow(m) == 0L)
-        NaN ## base::mean returns NaN with zero-length 'x'
-    else {
-        m <- 1 * m
-        ans <- matrixStats::rowMeans2(m, na.rm = na_rm)
-        names(ans) <- rownames(m)
-        ans
-    }
+  check_flag(na_rm)
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    NaN ## base::mean returns NaN with zero-length 'x'
+  else {
+    m <- 1 * m
+    ans <- matrixStats::rowMeans2(m, na.rm = na_rm)
+    names(ans) <- rownames(m)
+    ans
+  }
 }
 
 ## HAS_TESTS
 #' @rdname draws_median
 #' @export
 draws_mean.rvec_chr <- function(x, na_rm = FALSE) {
-    cli::cli_abort("Mean not defined for character.")
+  cli::cli_abort("Mean not defined for character.")
 }
 
 #' @rdname draws_median
 #' @export
 draws_mode <- function(x, na_rm = FALSE) {
-    UseMethod("draws_mode")
+  UseMethod("draws_mode")
 }
 
 ## HAS_TESTS
 #' @rdname draws_median
 #' @export
 draws_mode.rvec <- function(x, na_rm = FALSE) {
-    check_flag(na_rm)
-    m <- field(x, "data")
-    storage_mode <- storage.mode(m)
-    if (nrow(m) == 0L) {
-        ans <- NA
-    }
-    else {
-        useNA <- if (na_rm) "no" else "ifany"
-        tabs <- apply(m, 1L, table, useNA = useNA, simplify = FALSE)
-        nms_tabs <- lapply(tabs, names)
-        i_max <- lapply(tabs, function(x) which(x == max(x))) # allows multiple
-        has_unique_mode <- vapply(i_max, length, 1L) == 1L
-        ans <- rep(NA, times = nrow(m))
-        modes <- .mapply(function(x, i) x[[i]],
-                         dots = list(nms_tabs[has_unique_mode],
-                                     i_max[has_unique_mode]),
-                         MoreArgs = list())
-        modes <- unlist(modes, use.names = FALSE)
-        ans[has_unique_mode] <- modes
-        names(ans) <- rownames(m)
-    }
-    storage.mode(ans) <- storage_mode
-    ans
+  check_flag(na_rm)
+  m <- field(x, "data")
+  storage_mode <- storage.mode(m)
+  if (nrow(m) == 0L) {
+    ans <- NA
+  }
+  else {
+    useNA <- if (na_rm) "no" else "ifany"
+    tabs <- apply(m, 1L, table, useNA = useNA, simplify = FALSE)
+    nms_tabs <- lapply(tabs, names)
+    i_max <- lapply(tabs, function(x) which(x == max(x))) # allows multiple
+    has_unique_mode <- vapply(i_max, length, 1L) == 1L
+    ans <- rep(NA, times = nrow(m))
+    modes <- .mapply(function(x, i) x[[i]],
+                     dots = list(nms_tabs[has_unique_mode],
+                                 i_max[has_unique_mode]),
+                     MoreArgs = list())
+    modes <- unlist(modes, use.names = FALSE)
+    ans[has_unique_mode] <- modes
+    names(ans) <- rownames(m)
+  }
+  storage.mode(ans) <- storage_mode
+  ans
 }
 
 
@@ -395,18 +386,15 @@ draws_mode.rvec <- function(x, na_rm = FALSE) {
 #' - [draws_median()] 
 #' - [draws_mean()]
 #' - [draws_mode()]
+#' - [draws_sd()]
+#' - [draws_var()]
+#' - [draws_cv()]
 #' - [draws_ci()]
 #' - [draws_quantile()]
 #'
 #' Apply arbitrary function across draws:
 #' - [draws_fun()]
 #'
-#' For additional functions for summarising random draws, see
-#' [tidybayes](https://CRAN.R-project.org/package=tidybayes)
-#' and [ggdist](https://CRAN.R-project.org/package=ggdist).
-#' Function [as_list_col()] converts rvecs into a
-#' format that `tidybayes` and `ggdist` can work with.
-#'
 #' @examples
 #' m <- rbind(a = c(1,  -3,  2),
 #'            b = c(Inf,  0,   -Inf),
@@ -417,13 +405,13 @@ draws_mode.rvec <- function(x, na_rm = FALSE) {
 #' draws_max(x)
 #' @export
 draws_min <- function(x, na_rm = FALSE) {
-    UseMethod("draws_min")
+  UseMethod("draws_min")
 }
 
 #' @rdname draws_min
 #' @export
 draws_max <- function(x, na_rm = FALSE) {
-    UseMethod("draws_max")
+  UseMethod("draws_max")
 }
 
 ## HAS_TESTS
@@ -484,7 +472,7 @@ draws_max.rvec <- function(x, na_rm = FALSE) {
 #' Quantiles Across Random Draws
 #'
 #' Summarise the distribution of random draws
-#' in an `rvec`, using quantiles.
+#' in an rvec, using quantiles.
 #'
 #' The `probs` argument defaults to
 #' `c(0.025, 0.25, 0.5, 0.75, 0.975)`,
@@ -518,22 +506,19 @@ draws_max.rvec <- function(x, na_rm = FALSE) {
 #' functions across draws are:
 #' - [draws_all()]
 #' - [draws_any()]
-#' - [draws_ci()]
 #' - [draws_min()]
 #' - [draws_max()]
 #' - [draws_median()]
 #' - [draws_mean()]
 #' - [draws_mode()]
+#' - [draws_sd()]
+#' - [draws_var()]
+#' - [draws_cv()]
+#' - [draws_ci()]
 #'
 #' Apply arbitrary function across draws:
 #' - [draws_fun()]
 #'
-#' For additional functions for summarising random draws, see
-#' [tidybayes](https://CRAN.R-project.org/package=tidybayes)
-#' and [ggdist](https://CRAN.R-project.org/package=ggdist).
-#' Function [as_list_col()] converts rvecs into a
-#' format that `tidybayes` and `ggdist` can work with.
-#'
 #' @examples
 #' set.seed(0)
 #' m <- rbind(a = rnorm(100, mean = 5, sd = 2),
@@ -559,7 +544,7 @@ draws_max.rvec <- function(x, na_rm = FALSE) {
 draws_quantile <- function(x,
                            probs = c(0.025, 0.25, 0.5, 0.75, 0.975),
                            na_rm = FALSE) {
-    UseMethod("draws_quantile")
+  UseMethod("draws_quantile")
 }
 
 ## HAS_TESTS
@@ -568,25 +553,25 @@ draws_quantile <- function(x,
 draws_quantile.rvec <- function(x,
                                 probs = c(0.025, 0.25, 0.5, 0.75, 0.975),
                                 na_rm = FALSE) {
-    x_str <- deparse1(substitute(x))
-    check_probs(probs)
-    check_flag(na_rm)
-    m <- field(x, "data")
-    if (nrow(m) == 0L)
-        ans <- stats::quantile(double(), probs = probs)
-    else {
-        ans <- matrixStats::rowQuantiles(m,
-                                         probs = probs,
-                                         na.rm = na_rm,
-                                         drop = FALSE)
-        ans <- matrix_to_list_of_cols(ans)
-    }
-    nms <- names(ans)
-    nms <- sub("%$", "", nms)
-    nms <- paste(x_str, nms, sep = "_")
-    names(ans) <- nms
-    ans <- tibble::tibble(!!!ans)
-    ans
+  x_str <- deparse1(substitute(x))
+  check_probs(probs)
+  check_flag(na_rm)
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    ans <- stats::quantile(double(), probs = probs)
+  else {
+    ans <- matrixStats::rowQuantiles(m,
+                                     probs = probs,
+                                     na.rm = na_rm,
+                                     drop = FALSE)
+    ans <- matrix_to_list_of_cols(ans)
+  }
+  nms <- names(ans)
+  nms <- sub("%$", "", nms)
+  nms <- paste(x_str, nms, sep = "_")
+  names(ans) <- nms
+  ans <- tibble::tibble(!!!ans)
+  ans
 }
 
 ## HAS_TESTS
@@ -595,7 +580,136 @@ draws_quantile.rvec <- function(x,
 draws_quantile.rvec_chr <- function(x,
                                     probs = c(0.025, 0.25, 0.5, 0.75, 0.975),
                                     na_rm = FALSE) {
-    cli::cli_abort("Quantiles not defined for character.")
+  cli::cli_abort("Quantiles not defined for character.")
+}
+
+
+#' Standard Deviations, Variances, and Coefficients
+#' of Variation Across Random Draws
+#'
+#' Use standard deviations, variances, or
+#' coefficients of variation to
+#' summarise the distribution of random draws
+#' in an rvec.
+#'
+#' The coefficient of variation is the standard
+#' deviation divided by the mean.
+#'
+#' @inheritParams draws_all
+#'
+#' @returns A vector.
+#'
+#' @seealso
+#' Apply pre-specified functions across draws:
+#' - [draws_all()]
+#' - [draws_any()]
+#' - [draws_mean()]
+#' - [draws_median()]
+#' - [draws_mode()]
+#' - [draws_min()]
+#' - [draws_max()]
+#' - [draws_ci()]
+#' - [draws_quantile()]
+#'
+#' Apply arbitrary function across draws:
+#' - [draws_fun()]
+#'
+#' @examples
+#' m <- rbind(a = c(1, 1, 1, 2, 3),
+#'            b = c(2, 4, 0, 2, 3),
+#'            c = c(0, 0, 1, 0, 100))
+#' x <- rvec(m)
+#' x
+#' draws_sd(x)
+#' draws_var(x)
+#' draws_cv(x)
+#' @export
+draws_sd <- function(x, na_rm = FALSE) {
+  UseMethod("draws_sd")
+}
+
+## HAS_TESTS
+#' @rdname draws_sd
+#' @export
+draws_sd.rvec_chr <- function(x, na_rm = FALSE) {
+  cli::cli_abort("Standard deviation not defined for character.")
+}
+
+## HAS_TESTS
+#' @rdname draws_sd
+#' @export
+draws_sd.rvec <- function(x, na_rm = FALSE) {
+  check_flag(na_rm)
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    NA_real_ ## stats::sd returns NA with zero-length 'x'
+  else {
+    m <- 1 * m
+    ans <- matrixStats::rowSds(m, na.rm = na_rm)
+    names(ans) <- rownames(m)
+    ans
+  }
+}
+
+#' @rdname draws_sd
+#' @export
+draws_var <- function(x, na_rm = FALSE) {
+  UseMethod("draws_var")
+}
+
+## HAS_TESTS
+#' @rdname draws_sd
+#' @export
+draws_var.rvec_chr <- function(x, na_rm = FALSE) {
+  cli::cli_abort("Variance not defined for character.")
+}
+
+## HAS_TESTS
+#' @rdname draws_sd
+#' @export
+draws_var.rvec <- function(x, na_rm = FALSE) {
+  check_flag(na_rm)
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    NA_real_ ## stats::var returns NA with zero-length 'x'
+  else {
+    m <- 1 * m
+    ans <- matrixStats::rowVars(m, na.rm = na_rm)
+    names(ans) <- rownames(m)
+    ans
+  }
+}
+
+#' @rdname draws_sd
+#' @export
+draws_cv <- function(x, na_rm = FALSE) {
+  UseMethod("draws_cv")
+}
+
+## HAS_TESTS
+#' @rdname draws_sd
+#' @export
+draws_cv.rvec_chr <- function(x, na_rm = FALSE) {
+  cli::cli_abort("Coefficient of variation not defined for character.")
+}
+
+## HAS_TESTS
+#' @rdname draws_sd
+#' @export
+draws_cv.rvec <- function(x, na_rm = FALSE) {
+  check_flag(na_rm)
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    NA_real_ ## stats::var returns NA with zero-length 'x'
+  else {
+    m <- 1 * m
+    numerator <- matrixStats::rowSds(m, na.rm = na_rm)
+    denominator <- matrixStats::rowMeans2(m, na.rm = na_rm)
+    ans <- numerator / denominator
+    ans[denominator == 0] <- NA_real_
+    names(ans) <- rownames(m)
+    ans
+  }
 }
 
 
@@ -604,7 +718,7 @@ draws_quantile.rvec_chr <- function(x,
 #' Apply Summary Function Across Random Draws
 #'
 #' Summarise the distribution of random draws
-#' in an `rvec`, using a function.
+#' in an rvec, using a function.
 #'
 #' @inheritParams draws_all
 #' @param fun A function.
@@ -617,12 +731,15 @@ draws_quantile.rvec_chr <- function(x,
 #' Apply pre-specified functions across draws:
 #' - [draws_all()]
 #' - [draws_any()]
-#' - [draws_ci()]
 #' - [draws_min()]
 #' - [draws_max()]
 #' - [draws_median()]
 #' - [draws_mean()]
 #' - [draws_mode()]
+#' - [draws_sd()]
+#' - [draws_var()]
+#' - [draws_cv()]
+#' - [draws_ci()]
 #' - [draws_quantile()]
 #'
 #' @examples
@@ -638,26 +755,26 @@ draws_quantile.rvec_chr <- function(x,
 #' draws_fun(x, function(x) sd(x) / mean(x))
 #' @export
 draws_fun <- function(x, fun, ...) {
-    UseMethod("draws_fun")
+  UseMethod("draws_fun")
 }
 
 ## HAS_TESTS
 #' @rdname draws_fun
 #' @export
 draws_fun.rvec <- function(x, fun, ...) {
-    m <- field(x, "data")
-    if (nrow(m) == 0L)
-        return(list())
-    fun <- match.fun(fun)
-    l <- matrix_to_list_of_rows(m)
-    for (i in seq_along(l))
-        l[[i]] <- fun(l[[i]], ...)
-    is_atomic <- vapply(l, is.atomic, TRUE)
-    lengths <- lengths(l)
-    if (all(is_atomic) && all(lengths == 1L))
-        vec_c(!!!l)
-    else
-        l
+  m <- field(x, "data")
+  if (nrow(m) == 0L)
+    return(list())
+  fun <- match.fun(fun)
+  l <- matrix_to_list_of_rows(m)
+  for (i in seq_along(l))
+    l[[i]] <- fun(l[[i]], ...)
+  is_atomic <- vapply(l, is.atomic, TRUE)
+  lengths <- lengths(l)
+  if (all(is_atomic) && all(lengths == 1L))
+    vec_c(!!!l)
+  else
+    l
 }
 
 
