@@ -1,3 +1,4 @@
+
 #' Package 'rvec'
 #'
 #' Tools for working with random draws from a distribution, eg
@@ -21,14 +22,18 @@
 #' - [rvec_int()] Integers
 #' - [rvec_lgl()] Logical
 #' - [rvec_chr()] Character
+#' - [new_rvec_dbl()] Empty doubles
+#' - [new_rvec_int()] Empty integers
+#' - [new_rvec_lgl()] Empty logical
+#' - [new_rvec_chr()] Empty character
 #' - [collapse_to_rvec()] Data in data frame
-#' - [new_rvec()] Blanks
 #'
 #' **Manipulating rvecs**
 #'
 #' - [if_else_rvec()] `if_else()` where `condition` is rvec
 #' - [map_rvec()] `map()` for rvecs
 #' - [extract_draw()] Single draw from rvec
+#' - [pool_draws()] Combine samples
 #'
 #' **Probability distributions**
 #'
@@ -52,17 +57,20 @@
 #'
 #' **Summarizing across draws**
 #'
-#' - [draws_all()] All draws
-#' - [draws_any()] Any draws
-#' - [draws_min()] Minimum draw
-#' - [draws_max()] Maximum draw
-#' - [draws_median()] Median draw
-#' - [draws_mean()] Mean draw 
-#' - [draws_mode()] Modal draw
+#' - [draws_all()] All
+#' - [draws_any()] Any
+#' - [draws_min()] Minimum
+#' - [draws_max()] Maximum
+#' - [draws_median()] Median
+#' - [draws_mean()] Mean
+#' - [draws_mode()] Modal
+#' - [draws_sd()] Standard deviation
+#' - [draws_var()] Variances
+#' - [draws_cv()] Coefficients of variation
 #' - [draws_ci()] Credible intervals
 #' - [draws_quantile()] Quantiles
 #' - [draws_fun()] Arbitrary function
-#' - [n_draw()] Number of draws
+#' - [n_draw()] Number
 #'
 #' **Coercion, classes**
 #'
@@ -91,18 +99,16 @@
 #' @aliases rvec-package NULL
 #' @import vctrs
 #' @importFrom methods setOldClass
+#' @importFrom methods setMethod
+#' @importFrom Matrix Matrix
 #' @importFrom stats median
 #' @importFrom utils globalVariables
 "_PACKAGE"
 
 ## usethis namespace: start
+#' @importFrom lifecycle deprecated
 ## usethis namespace: end
 NULL
 
 globalVariables('value') ## to allow use in collapse_to_rvec
 
-## for compatibility with the S4 system
-setOldClass(c("rvec_chr", "rvec", "vctrs_vctr"))
-setOldClass(c("rvec_dbl", "rvec", "vctrs_vctr"))
-setOldClass(c("rvec_int", "rvec", "vctrs_vctr"))
-setOldClass(c("rvec_lgl", "rvec", "vctrs_vctr"))
